pub struct LoadMetric(pub f64);Expand description
A comparable predicted completion cost for P2C selection.
Lower values are better. The value is measured in seconds from the moment the metric was read and includes the endpoint’s expected RTT.
Tuple Fields
0: f64Implementations